cheesecake.codeparser.CodeParser

Package cheesecake :: Module codeparser :: Class CodeParser |
[hide private]
[frames] | no frames]

## Class CodeParser
source code

    object --+
             |
            CodeParser

Information about the structure of a Python module.

- Collects modules, classes, methods, functions and associated docstrings
- Based on mwh's docextractor.model module

Instance Methods | [hide private]
| __init__(self, pyfile, log=None) Initialize Code Parser object.
| object_count(self) Return number of objects found in this module.
| docstring_count(self) Return number of docstrings found in this module.
| docstring_count_by_type(self, type) Return number of docstrings of given type found in this module.
| _functions_called(self) Return list of functions called by functions/methods defined in this module.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Properties | [hide private]
functions_called |

Method Details | [hide private]

### __init__(self, pyfile, log=None) (Constructor) | source code
Initialize Code Parser object. Parameters: `pyfile` (`str`) - Path to a Python module to parse. `log` (`logger.Producer instance`) - Logger to use during code parsing. Overrides: object.__init__

### object_count(self) | source code
Return number of objects found in this module. Objects include: * module * classes * methods * functions

### docstring_count(self) | source code
Return number of docstrings found in this module.

### docstring_count_by_type(self, type) | source code
Return number of docstrings of given type found in this module.

### _functions_called(self) | source code
Return list of functions called by functions/methods defined in this module.

Property Details | [hide private]

### functions_called Get Method: cheesecake.codeparser.CodeParser._functions_called(self) - Return list of functions called by functions/methods defined in this module. Set Method: None Delete Method: None